#!/bin/bash -ex
# Copyright start
# Copyright (C) 2008 - 2020 Fortinet Inc.
# All rights reserved.
# FORTINET CONFIDENTIAL & FORTINET PROPRIETARY SOURCE CODE
# Copyright end

# This scipt change the soft/hard limit of os and 
# add delete of rabbitmq user, set_permissions for rabbitmq user.

init(){
    cyops_guest="guest"
    cyops_user="cyops"
    cyops_role="administrator"
    cyops_vhost="intra-cyops"
    rabbitmq_config_file="rabbitmq-defaults"
    cyops_passwd_file="rabbitmq_users.conf"
    cyops_passwd_file_path="/opt/cyops/configs/rabbitmq"
    rabbitmq_ctl="/sbin/rabbitmqctl"
    rabbitmq_version=`$rabbitmq_ctl --version`
    cyops_rabbitmq_config="/usr/lib/rabbitmq/lib/rabbitmq_server-${rabbitmq_version}/sbin"
    f_sysctl="/etc/sysctl.conf"
    f_rb_service="/usr/lib/systemd/system/rabbitmq-server.service"
    f_limit="/etc/security/limits.conf"

    rb_user=`$rabbitmq_ctl list_users | grep $cyops_user | awk '{print $1}'`
    rb_vhost=`$rabbitmq_ctl list_users | grep $cyops_vhost`

    f_release_file="/etc/cyops-release"
    s_product_type=`cat $f_release_file | cut -d'=' -f2`

}

set_os_limit(){
   # Change the OS and rabbitmq soft/hard limit
   os_limit=`ulimit -a | grep -A 1 "max memory size" | grep "open files" | awk '{print $4}'`
   # This is for fresh and update the CyOps.
   if [  $os_limit -le 65535 ]; then

      i_file_max=`grep fs.file-max $f_sysctl | awk '{print $3}'`
      if [ "$i_file_max" != "100000" ];then
         sed -i '$ i\fs.file-max = 100000' $f_sysctl
      fi

      grep -w "LimitNOFILE=65535" $f_rb_service
      if [ $? != 0 ];then
         sed -i '/LimitNOFILE/a LimitNOFILE=65535' $f_rb_service
      fi

      i_soft_nproc=`grep "soft nproc 65535" $f_limit | awk '{print $4}'`
      i_hard_nproc=`grep "hard nproc 65535" $f_limit | awk '{print $4}'`
      i_soft_nofile=`grep "soft nofile 65535" $f_limit | awk '{print $4}'`
      i_hard_nofile=`grep "hard nofile 65535" $f_limit | awk '{print $4}'`
      if [ "$i_soft_nproc" != "65535" ] && [ "$i_hard_nproc" != "65535" ] && [ "$i_soft_nofile" != "65535" ] && [ "$i_hard_nofile" != "65535" ];then
         sed -i -e '$a\
         * soft nproc 65535\
         * hard nproc 65535\
         * soft nofile 65535\
         * hard nofile 65535' $f_limit
         sudo sysctl -p
         systemctl daemon-reload
      fi
   fi
}

create_db(){
    echo "User process started."
    if [ -f $cyops_passwd_file_path/$cyops_passwd_file ]; then
       cyops_passwd=`grep "cyops.rabbitmq.password" $cyops_passwd_file_path/$cyops_passwd_file | cut -d"=" -f2`
       $rabbitmq_ctl delete_user $cyops_guest
       $rabbitmq_ctl add_user cyops $cyops_passwd
       $rabbitmq_ctl set_user_tags $cyops_user $cyops_role
       $rabbitmq_ctl add_vhost $cyops_vhost
       $rabbitmq_ctl set_permissions -p $cyops_vhost $cyops_user ".*" ".*" ".*"
       sed -i  '0,/etc\/rabbitmq\/rabbitmq/s//etc\/rabbitmq\/rabbitmq.conf/' $cyops_rabbitmq_config/$rabbitmq_config_file
       chown -R root:rabbitmq /opt/cyops/configs/rabbitmq/
    fi
}

#### Main ######

init

if [[ "$rb_user" != "$cyops_user" &&  "$rb_vhost" != "$cyops_vhost" ]];then
    if [ $s_product_type = "secure-message-exchange" ];then
        set_os_limit
    else
        set_os_limit
        create_db
    fi
fi
