#!/bin/bash -ex
# Copyright start
# Copyright (C) 2008 - 2020 Fortinet Inc.
# All rights reserved.
# FORTINET CONFIDENTIAL & FORTINET PROPRIETARY SOURCE CODE
# Copyright end

# This script will generate self-signed certs for rabbitmq
# and assigned to the rabbitmq configuration.

rabbitmq_cyops_conf="/opt/cyops-rabbitmq/configs/ssl"
rabbitmq_conf="/etc/rabbitmq/"
rabbitmq_conf_file="rabbitmq.config"
rabbitmq_ssl="/opt/cyops/configs/rabbitmq/ssl"
rabbitmq_work="work"
cyopsca_certs="$rabbitmq_cyops_conf/$rabbitmq_work/cyopsca"
server_certs="$rabbitmq_cyops_conf/$rabbitmq_work/server"
server_private="$cyopsca_certs/private"
rabbitmq_server_certs="$cyopsca_certs/certs"
client_certs="$rabbitmq_cyops_conf/$rabbitmq_work/client"
cyopsca_cacert_pem="cacert.pem"
server_cert_pem="cert.pem"
server_key_pem="key.pem"
openssl_conf_file="openssl.cnf"

create_dir()
{
   echo "The creating directory structure."
   mkdir -p $cyopsca_certs
   mkdir -p $server_certs
   mkdir -p $rabbitmq_server_certs
   mkdir -p $server_private
   mkdir -p $client_certs
   echo 01 > $cyopsca_certs/serial
   touch $cyopsca_certs/index.txt
   cp $rabbitmq_cyops_conf/$openssl_conf_file $rabbitmq_conf
}

create_certs_cyopsca()
{
  echo "The cyopsca certificates in process"

  if [ -d "$cyopsca_certs" ]; then
     cd $cyopsca_certs
     openssl req -x509 -config $rabbitmq_conf/openssl.cnf -newkey rsa:2048 -days 365 \
     -out cacert.pem -outform PEM -subj /CN=MyTestCA/ -nodes
     openssl x509 -in cacert.pem -out cacert.cer -outform DER
    if [ $? != 0 ];then
        echo "create_certs_cyopsca function failed."
        exit 1
     fi
  else
    echo "The dir $cyopsca_certs not exist."
    exit 1
  fi
  echo "The certificates created"

}

create_certs()
{
   echo "The pem file in process."
   cert_path=$1
   # Create cert for server
        echo $cert_path
        cd $cert_path
        openssl genrsa -out key.pem 2048
   if [ -d "$cert_path" ]; then
      if [ "$cert_path" = "$rabbitmq_cyops_conf/$rabbitmq_work/server" ];then
         openssl req -new -key key.pem -out req.pem -outform PEM -subj /CN=$(hostname -f)/O=server/ -nodes
         cd $cyopsca_certs
         openssl ca -config $rabbitmq_conf/openssl.cnf -in $cert_path/req.pem -out $cert_path/cert.pem -notext -batch -extensions server_ca_extensions
      else
         openssl req -new -key key.pem -out req.pem -outform PEM -subj /CN="client1"/O=client/ -nodes
         cd $cyopsca_certs
         openssl ca -config $rabbitmq_conf/openssl.cnf -in $cert_path/req.pem -out $cert_path/cert.pem -notext -batch -extensions client_ca_extensions
      fi

      cd $cert_path
      openssl pkcs12 -export -out $cert_path/keycert.p12 -in $cert_path/cert.pem -inkey $cert_path/key.pem -passout pass:changeme

      chown -R root:rabbitmq $rabbitmq_ssl
      chown -R root:rabbitmq $cyopsca_certs
      chown -R root:rabbitmq $server_certs
      chown -R root:rabbitmq $client_certs
      chown -R root:rabbitmq $rabbitmq_cyops_conf/$rabbitmq_work
      chmod -R 755 $rabbitmq_cyops_conf/$rabbitmq_work

      if [ $? != 0 ];then
         echo "create_certs function failed."
         exit 1
      fi
   else
      echo "The dir $cert_path not exist."
      exit 1
   fi
   echo "The pem file created."
}

# Main functions start.

if [ -d $rabbitmq_cyops_conf/$rabbitmq_work ];then
   rm -rf $rabbitmq_cyops_conf/$rabbitmq_work
fi

if [ -d $rabbitmq_ssl/cyopsca ];then
   rm -rf $rabbitmq_ssl/cyopsca
fi

if [ -d $rabbitmq_ssl/server ];then
    rm -rf $rabbitmq_ssl/server
fi

create_dir
create_certs_cyopsca
create_certs $server_certs
create_certs $client_certs
cp -rf $server_certs $rabbitmq_ssl
cp -rf $cyopsca_certs $rabbitmq_ssl
chown -R root:rabbitmq $rabbitmq_ssl
echo "Restarting rabbitmq-server"
systemctl restart rabbitmq-server
if [ $? -ne 0 ]; then
    echo "Failed to restart rabbitmq-server"
fi
